@@ -7,6 +7,7 @@ import logging
 from Acquisition import aq_inner
 from Acquisition import aq_parent
 from AccessControl import getSecurityManager
+from zExceptions import Unauthorized
 from five import grok
 from zope.interface import directlyProvides
 from zope.interface import directlyProvidedBy
@@ -77,6 +78,12 @@ class View(grok.View):
     def _ContinueSurvey(self, info):
         """Utility method to continue an existing session."""
         session = Session.query(model.SurveySession).get(info["session"])
+        current_user = aq_base(getSecurityManager().getUser())
+        if session.account is not current_user:
+            log.warn('User %s tried to hijack session from %s',
+                    getattr(current_user, 'loginname', repr(current_user)),
+                    session.account.loginname)
+            raise Unauthorized()
         SessionManager.resume(session)
         survey = self.request.client.restrictedTraverse(str(session.zodb_path))
         self.request.response.redirect("%s/resume" % survey.absolute_url())
@@ -200,8 +207,7 @@ class Evaluation(grok.View):
     grok.template("evaluation")
     grok.name("index_html")
 
-    question_filter = sql.or_(model.MODULE_WITH_RISK_NO_TOP5_NO_POLICY_FILTER,
-                              model.RISK_PRESENT_NO_TOP5_NO_POLICY_FILTER)
+    question_filter = model.EVALUATION_FILTER
 
     def update(self):
         if redirectOnSurveyUpdate(self.request):
@@ -231,8 +237,7 @@ class ActionPlan(grok.View):
     grok.template("actionplan")
     grok.name("index_html")
 
-    question_filter = sql.or_(model.MODULE_WITH_RISK_OR_TOP5_FILTER,
-                              model.RISK_PRESENT_OR_TOP5_FILTER)
+    question_filter = model.ACTION_PLAN_FILTER
 
     def update(self):
         if redirectOnSurveyUpdate(self.request):
