@@ -7,11 +7,13 @@ structure containing modules, profile questions and questions. Both modules and
 profile questions are used to create the hierarchy.
 """
 
+import sys
 from Acquisition import aq_inner
 from Acquisition import aq_parent
 from ZODB.POSException import ConflictError
 from OFS.event import ObjectClonedEvent
 from zope.interface import implements
+from zope.component import adapts
 from zope.component import getMultiAdapter
 from zope.event import notify
 from zope import schema
@@ -22,18 +24,22 @@ from plone.directives import form
 from plone.directives import dexterity
 from plone.app.z3cform.wysiwyg import WysiwygFieldWidget
 from plone.app.dexterity.behaviors.metadata import IBasic
-from htmllaundry.z3cform import HtmlText
-from Products.statusmessages.interfaces import IStatusMessage
-from Products.Archetypes.utils import shasattr
-from .. import MessageFactory as _
-from euphorie.content.profilequestion import IProfileQuestion
-from euphorie.content.module import IModule
-from euphorie.content.interfaces import IQuestionContainer
-from euphorie.content.interfaces import ISurveyUnpublishEvent
-from euphorie.content.utils import StripMarkup
 from plonetheme.nuplone.skin.interfaces import NuPloneSkin
 from plonetheme.nuplone.skin import actions
 from plone.indexer import indexer
+from htmllaundry.z3cform import HtmlText
+from Products.statusmessages.interfaces import IStatusMessage
+from Products.Archetypes.utils import shasattr
+from .behaviour.uniqueid import INameFromUniqueId
+from .behaviour.uniqueid import get_next_id
+from .profilequestion import IProfileQuestion
+from .module import IModule
+from .fti import check_fti_paste_allowed
+from .interfaces import IQuestionContainer
+from .interfaces import ISurveyUnpublishEvent
+from .utils import StripMarkup
+from .datamanager import ParentAttributeField
+from .. import MessageFactory as _
 
 
 grok.templatedir("templates")
@@ -91,6 +97,14 @@ class ISurvey(form.Schema, IBasic):
             required=False)
 
 
+
+class SurveyAttributeField(ParentAttributeField):
+    parent_mapping = {
+            'survey_title': 'title',
+            'obsolete': 'obsolete',
+    }
+
+
 class Survey(dexterity.Container):
     """A risk assessment survey.
 
@@ -107,7 +121,29 @@ class Survey(dexterity.Container):
         """Tell Zope2 that this object can not be copied."""
         return False
 
+    def _get_id(self, orig_id):
+        """Pick an id for pasted content."""
+        frame = sys._getframe(1)
+        ob = frame.f_locals.get('ob')
+        if ob is not None and INameFromUniqueId.providedBy(ob):
+            return get_next_id(self)
+        return super(Survey, self)._get_id(orig_id)
+
+    def _verifyObjectPaste(self, object, validate_src=True):
+        super(Survey, self)._verifyObjectPaste(object, validate_src)
+        if validate_src:
+            check_fti_paste_allowed(self, object)
+
     @property
+    def surveygroup_title(self):
+        import pdb ; pdb.set_trace()
+        return u'Oops'
+
+    @surveygroup_title.setter
+    def surveygroup_title(self, value):
+        import pdb ; pdb.set_trace
+        print value
+
     def hasProfile(self):
         """Check if this survey has any profile questions.
 
@@ -167,6 +203,26 @@ class ISurveyAddSchema(form.Schema):
             required=True)
 
 
+class ISurveyEditSchema(ISurvey):
+    survey_title = schema.TextLine(
+            title=_("label_title", default=u"Title"),
+            description=_("help_surveygroup_title",
+                default=u"The title of this survey. This title is used in "
+                        u"the survey overview in the clients."),
+            required=True)
+    form.order_before(survey_title="*")
+
+    obsolete = schema.Bool(
+            title=_("label_survey_obsolete",
+                default=u"Obsolete survey"),
+            description=_("help_survey_obsolete",
+                default=u"This survey is obsolete; it has been retired or "
+                        u"replaced with another survey."),
+            default=False,
+            required=False)
+    form.order_before(obsolete="introduction")
+
+
 class AddForm(dexterity.AddForm):
     """Custom add form for :obj:`Survey` instances. This form is
     needlessly complicated: it should use a schema and a vocabulary
@@ -215,6 +271,15 @@ class AddForm(dexterity.AddForm):
         return survey
 
 
+class Edit(form.SchemaEditForm):
+    grok.context(ISurvey)
+    grok.require("cmf.ModifyPortalContent")
+    grok.layer(NuPloneSkin)
+    grok.name("edit")
+
+    schema = ISurveyEditSchema
+
+
 class Delete(actions.Delete):
     """Special delete action class which prevents deletion of published surveys
     or of the last survey in a group.
